==> openrm-devel-1.6.0-1.tar.gz: rm160/rm/rmversion.c <==
/*
 * Copyright (C) 1997-2005, R3vis Corporation.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA, or visit http://www.gnu.org/copyleft/lgpl.html.
 *
 * Original Contributor:
 *   Wes Bethel, R3vis Corporation, Marin County, California
 * Additional Contributor(s):
 *
 * The OpenRM project is located at http://openrm.sourceforge.net/.
 */
/*
 * $Id: rmversion.c,v 1.16 2005/07/23 16:21:25 wes Exp $
 * Version: $Name: OpenRM-1-6-0-RC5 $
 * $Revision: 1.16 $
 */

#include <rm/rm.h>
#include "rmprivat.h"

static char version[] = "(v1.6.0)";
static char rmsgbanner[] = "OpenRM Scene Graph %s, \nCopyright (C) 1999-2005, R3vis Corporation.";

/* PRIVATE */
int
private_rmHello (void)
{
    char bigbuf[512];

    /* everybody gets the copyright notice */
    sprintf(bigbuf, rmsgbanner, version);
    rmSplash(bigbuf);

    return(1);
}
/* EOF */

==> openrm-devel-1.6.0-2.tar.gz: rm160/rm/rmversion.c <==
/*
 * Copyright (C) 1997-2005, R3vis Corporation.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA, or visit http://www.gnu.org/copyleft/lgpl.html.
 *
 * Original Contributor:
 *   Wes Bethel, R3vis Corporation, Marin County, California
 * Additional Contributor(s):
 *
 * The OpenRM project is located at http://openrm.sourceforge.net/.
 */
/*
 * $Id: rmversion.c,v 1.17 2005/09/12 04:13:48 wes Exp $
 * Version: $Name: OpenRM-1-6-0-2-RC2 $
 * $Revision: 1.17 $
 */

#include <rm/rm.h>
#include "rmprivat.h"

static char version[] = "(v1.6.0-2)";
static char rmsgbanner[] = "OpenRM Scene Graph %s, \nCopyright (C) 1999-2005, R3vis Corporation.";

/* PRIVATE */
int
private_rmHello (void)
{
    char bigbuf[512];

    /* everybody gets the copyright notice */
    sprintf(bigbuf, rmsgbanner, version);
    rmSplash(bigbuf);

    return(1);
}
/* EOF */
